pycocoa.windows.MediaWindow

Package pycocoa :: Module windows :: Class MediaWindow |
[frames] | no frames]

# Class MediaWindow

              object --+
                       |
    internals._Objectype --+
                           |
            baseTypes._Type0 --+
                               |
                baseTypes._Type1 --+
                                   |
                    baseTypes._Type2 --+
                                       |
                                  Window --+
                                           |
                                          MediaWindow

Media window Python Type, wrapping ObjC `NSWindow/NSView`.

Instance Methods
__init__(self, title=`'``Media``'`, fraction=0.5, **kwds) Create a MediaWindow. |
Inherited from `Window`: `cascade`, `close`, `front`, `full`, `hide`, `limit`, `windowCloseOK_`, `windowClose_`, `windowKey_`, `windowMain_`, `windowPrint_`, `windowResize_`, `windowScreen_`, `windowZoomOK_`, `zoom` Inherited from `baseTypes._Type2`: `__str__` Inherited from `baseTypes._Type0`: `__repr__`, `type2strepr` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `Window`: `NSview`, `PMview`, `alpha`, `frame`, `isBuiltIn`, `isExternal`, `isFull`, `isFullScreen`, `isHidden`, `isKey`, `isMain`, `isPrintable`, `isVisible`, `isZoomed`, `opaque`, `ratio`, `screen`, `transparent`, `transparentTitlebar` Inherited from `baseTypes._Type2`: `title` Inherited from `baseTypes._Type1`: `NSdelegate`, `app` Inherited from `baseTypes._Type0`: `NS`, `NSDelegate` Inherited from `internals._Objectype`: `typename` Inherited from `object`: `__class__`

Method Details

### __init__(self, title=`'``Media``'`, fraction=0.5, **kwds) (Constructor) |
Create a MediaWindow. Parameters: `title` - Window name or title (string). `fraction` - Window size as fraction of the screen (`float`). `kwds` - Optional, additional keyword arguments, see Window. Raises: `WindowError` - Unique `Id` exists. Overrides: object.__init__